@@ -24,7 +24,7 @@
 #include <stdlib.h>
 #include <X11/keysym.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <gkbd-desktop-config.h>
 #include <gkbd-config-private.h>
@@ -276,7 +276,7 @@ gkbd_desktop_config_load_group_descriptions (GkbdDesktopConfig
 {
 	gchar **sld, **lld, **svd, **lvd;
 	gchar **psld, **plld, **plvd;
-	gchar **psgn, **pfgn;
+	gchar **psgn, **pfgn, **psvd;
 	gint total_descriptions;
 
 	if (!gkbd_desktop_config_get_lv_descriptions
@@ -295,10 +295,14 @@ gkbd_desktop_config_load_group_descriptions (GkbdDesktopConfig
 	plld = lld;
 	psld = sld;
 	plvd = lvd;
+	psvd = svd;
 	while (plld != NULL && *plld != NULL) {
-		*psgn++ = g_strdup (*psld++);
-		*pfgn++ = g_strdup (gkbd_keyboard_config_format_full_layout
-				    (*plld++, *plvd++));
+		*psgn++ = g_strdup ((*psvd[0] == '\0') ? *psld : *psvd);
+		*pfgn++ =
+		    g_strdup (gkbd_keyboard_config_format_full_description
+			      (*plld, *plvd));
+		psld++, psvd++;
+		plld++, plvd++;
 	}
 	g_strfreev (sld);
 	g_strfreev (lld);
