@@ -40,6 +40,8 @@
 
 #define CAIRO_LINE_WIDTH 1.0
 
+#define KEY_FONT_SIZE 12
+
 enum {
 	BAD_KEYCODE = 0,
 	NUM_SIGNALS
@@ -1518,7 +1520,7 @@ context_setup_scaling (GkbdKeyboardDrawingRenderContext * context,
 	}
 
 	pango_font_description_set_size (context->font_desc,
-					 720 * dpi_x *
+					 72 * KEY_FONT_SIZE * dpi_x *
 					 context->scale_numerator /
 					 context->scale_denominator);
 	pango_layout_set_spacing (context->layout,
