@@ -23,6 +23,7 @@
 #include <gtk/gtk.h>
 #include <X11/XKBlib.h>
 #include <X11/extensions/XKBgeom.h>
+#include <libxklavier/xklavier.h>
 
 G_BEGIN_DECLS
 #define GKBD_KEYBOARD_DRAWING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), gkbd_keyboard_drawing_get_type (), \
@@ -42,7 +43,9 @@ typedef struct _GkbdKeyboardDrawingRenderContext
  GkbdKeyboardDrawingRenderContext;
 
 typedef enum {
+	GKBD_KEYBOARD_DRAWING_ITEM_TYPE_INVALID = 0,
 	GKBD_KEYBOARD_DRAWING_ITEM_TYPE_KEY,
+	GKBD_KEYBOARD_DRAWING_ITEM_TYPE_KEY_EXTRA,
 	GKBD_KEYBOARD_DRAWING_ITEM_TYPE_DOODAD
 } GkbdKeyboardDrawingItemType;
 
@@ -55,7 +58,7 @@ typedef enum {
 	GKBD_KEYBOARD_DRAWING_POS_FIRST =
 	    GKBD_KEYBOARD_DRAWING_POS_TOPLEFT,
 	GKBD_KEYBOARD_DRAWING_POS_LAST =
-	    GKBD_KEYBOARD_DRAWING_POS_BOTTOMRIGHT,
+	    GKBD_KEYBOARD_DRAWING_POS_BOTTOMRIGHT
 } GkbdKeyboardDrawingGroupLevelPosition;
 
 /* units are in xkb form */
@@ -104,7 +107,7 @@ struct _GkbdKeyboardDrawingGroupLevel {
 };
 
 struct _GkbdKeyboardDrawingRenderContext {
-	cairo_t * cr;
+	cairo_t *cr;
 
 	gint angle;		/* current angle pango is set to draw at, in tenths of a degree */
 	PangoLayout *layout;
@@ -121,13 +124,13 @@ struct _GkbdKeyboardDrawing {
 
 	GtkDrawingArea parent;
 
-	GdkPixmap *pixmap;
 	XkbDescRec *xkb;
 	gboolean xkbOnDisplay;
 	guint l3mod;
 
 	GkbdKeyboardDrawingRenderContext *renderContext;
 
+	/* Indexed by keycode */
 	GkbdKeyboardDrawingKey *keys;
 
 	/* list of stuff to draw in priority order */
@@ -136,7 +139,6 @@ struct _GkbdKeyboardDrawing {
 	GdkColor *colors;
 
 	guint timeout;
-	guint idle_redraw;
 
 	GkbdKeyboardDrawingGroupLevel **groupLevels;
 
@@ -166,8 +168,6 @@ struct _GkbdKeyboardDrawingClass {
 GType gkbd_keyboard_drawing_get_type (void);
 GtkWidget *gkbd_keyboard_drawing_new (void);
 
-GdkPixbuf *gkbd_keyboard_drawing_get_pixbuf (GkbdKeyboardDrawing *
-					     kbdrawing);
 gboolean gkbd_keyboard_drawing_render (GkbdKeyboardDrawing * kbdrawing,
 				       cairo_t * cr,
 				       PangoLayout * layout,
@@ -178,6 +178,9 @@ gboolean gkbd_keyboard_drawing_set_keyboard (GkbdKeyboardDrawing *
 					     kbdrawing,
 					     XkbComponentNamesRec * names);
 
+void gkbd_keyboard_drawing_set_layout (GkbdKeyboardDrawing * kbdrawing,
+				       const gchar * id);
+
 G_CONST_RETURN gchar
     * gkbd_keyboard_drawing_get_keycodes (GkbdKeyboardDrawing * kbdrawing);
 G_CONST_RETURN gchar
@@ -200,5 +203,20 @@ void gkbd_keyboard_drawing_set_groups_levels (GkbdKeyboardDrawing *
 					      GkbdKeyboardDrawingGroupLevel
 					      * groupLevels[]);
 
+
+void gkbd_keyboard_drawing_print (GkbdKeyboardDrawing * drawing,
+				  GtkWindow * parent_window,
+				  const gchar * description);
+
+GtkWidget *gkbd_keyboard_drawing_dialog_new (void);
+
+void gkbd_keyboard_drawing_dialog_set_group (GtkWidget * dialog,
+					     XklConfigRegistry * registry,
+					     gint group);
+
+void gkbd_keyboard_drawing_dialog_set_layout (GtkWidget * dialog,
+					      XklConfigRegistry * registry,
+					      const gchar * layout);
+
 G_END_DECLS
 #endif				/* #ifndef GKBD_KEYBOARD_DRAWING_H */
